@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 2005-2022 The Octave Project Developers
+## Copyright (C) 2005-2024 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -53,13 +53,13 @@ function configure_make (desc, packdir, verbose)
     endif
 
     if (ispc () && ! isunix ())
-      # replace all backslashes with forward slashes
+      ## Replace all backslashes with forward slashes
       mkoctfile_program = strrep (mkoctfile_program, '\', '/');
       octave_config_program = strrep (octave_config_program, '\', '/');
       octave_binary = strrep (octave_binary, '\', '/');
     endif
 
-    # escape spaces in file paths unless they are already escaped
+    ## Escape spaces in file paths unless they are already escaped
     mkoctfile_program = regexprep (mkoctfile_program, '([^\\]) ', '$1\\ ');
     octave_config_program = regexprep (octave_config_program, ...
                                        '([^\\]) ', '$1\\ ');
