@@ -1,4 +1,9 @@
-## Copyright (C) 1995-2019 Friedrich Leisch
+########################################################################
+##
+## Copyright (C) 1995-2024 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -15,16 +20,17 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
-## @deftypefn {} {} triangle_sw (@var{n}, @var{b})
-## Triangular spectral window.  Subfunction used for spectral density
-## estimation.
+## @deftypefn {} {@var{retval} =} triangle_sw (@var{n}, @var{b})
+## Triangular spectral window.
+##
+## Subfunction used for spectral density estimation.
+## @seealso{spectral_xdf}
 ## @end deftypefn
 
-## Author: FL <Friedrich.Leisch@ci.tuwien.ac.at>
-## Description: Triangular spectral window
-
 function retval = triangle_sw (n, b)
 
   retval = zeros (n,1);
